@@ -17,30 +17,33 @@ echo ""
 
 NEEDPROG="wish"
 
-$ECHO "Looking for $NEEDPROG ... $END"
-FOUND=0
-OIFS="$IFS"
-IFS=":"
-# for d in `echo $PATH | sed -e 's/:/ /g'`; do
-for d in $PATH; do
-    if [ -x "$d/$NEEDPROG" ]; then
+for f in $NEEDPROG; do
+ 
+  $ECHO "Looking for $f ... $END"
+  FOUND=0
+  OIFS="$IFS"
+  IFS=":"
+
+  for d in $PATH; do
+    if [ -x "$d/$f" ]; then
         FOUND=1
-        DIR="$d"
         break
     fi
-done
-IFS="$OIFS"
+  done
 
-if [ $FOUND -eq 0 ]; then
-    echo  "Hmm, $NEEDPROG not found. You will need it to run 'ding'!"
-    $ECHO "Install anyway?  [y]/n: $END"
+  if [ $FOUND -eq 0 ]; then
+    echo  "Hmm, $f not found. You will need it to run 'ding'!"
+  eval $ECHO "Install anyway?  [y]/n: $END"
     read yn
     if [ "x$yn" = "xn" -o "x$yn" = "xN" ]; then
-        exit
+        exit 1
     fi
-else
-    echo "found in $DIR"
-fi
+  else
+    echo "found in $d"
+  fi
+  IFS="$OIFS"
+done
+
 echo ""
 
 OK=0
@@ -51,7 +54,7 @@ while [ $OK -eq 0 ] ; do
         BINDIR=$DEFBINDIR
     fi
     if [ ! -d $BINDIR ]; then
-        echo "No such directory: $BINDIR"
+        echo "Directory does not exist: $BINDIR"
     elif [ ! -w $BINDIR ]; then
         echo "Can't write to $BINDIR - no permissions!"
     else
@@ -66,7 +69,7 @@ while [ $OK -eq 0 ] ; do
         LIBDIR=$DEFLIBDIR
     fi 
     if [ ! -d $LIBDIR ]; then
-        echo "No such directory: $BINDIR"
+        echo "Directory does not exist: $LIBDIR"
     elif [ ! -w $LIBDIR ]; then
         echo "Can't write to $LIBDIR - no permissions!"
     else
@@ -75,7 +78,7 @@ while [ $OK -eq 0 ] ; do
 done                     
 
 echo ""
-$ECHO "Ok, install to $BINDIR and $LIBDIR? [y]/n: $END"
+$ECHO "Ready to install to $BINDIR and $LIBDIR? [y]/n: $END"
 read yn
 if [ "x$yn" != "xn" -a "x$yn" != "xN" ]; then
     sed -e "s#/usr/share/dict/ger-eng.txt#$LIBDIR/ger-eng.txt#" ding > /tmp/ding.$$
@@ -88,7 +91,7 @@ if [ "x$yn" != "xn" -a "x$yn" != "xN" ]; then
     chmod 644 "$LIBDIR/ger-eng.txt"
 else
     echo "Install aborted."
-    exit
+    exit 1
 fi
 echo ""
 if [ $? = 0 ]; then
